@@ -12,8 +12,9 @@ class Log_settings:
         logging.config.dictConfig(self.log_config)
 
     @classmethod
-    def logger_settings(cls, logger_config, container_name, db_info=None):
+    def logger_settings(cls, logger_config, container_name, db_info=None, db_type="postgresql"):
         """로그 설정
+        :param db_type: db 프로그램 종류
         :param db_info: 로그를 저장할 db
         :param container_name: db log에 들어갈 컨테이너 이름
         :param logger_config: logger 설정
@@ -21,7 +22,7 @@ class Log_settings:
         """
         # db 연결정보 입력시 db handler 설정
         if db_info is not None:
-            DatabaseHandler.init_db_adapter(container=container_name, db_info=db_info)
+            DatabaseHandler.init_db_adapter(container=container_name, db_info=db_info, db_type=db_type)
         # 기본 정의된 handler 사용
         cls.log_config = base_logger_config
         # logger만 입력받아서 사용
