@@ -9,6 +9,12 @@ Log_settings.logger_settings(
             "level": "DEBUG",
             "handlers": ["console"],
         },
+        "test_logger_console": {
+            "level": "INFO",
+            "handlers": ["console"],
+            # "propagate": True,
+            "propagate": False,
+        },
     },
     container_name="LoggerConsoleTest",
 )
